@@ -1,27 +1,19 @@
-from grow.common import markdown_extensions
-from grow.common import utils
-from grow.pods import urls
-from grow.pods import locales
+from . import formats
 from . import messages
-import jinja2
+from grow.common import utils
+from grow.pods import locales
+from grow.pods import urls
+import copy
 import json
 import logging
-import markdown
 import os
-import copy
 import re
-from markdown.extensions import tables
-from markdown.extensions import toc
 
 
 class Error(Exception):
   pass
 
 
-class BadFormatError(Error, ValueError):
-  pass
-
-
 class DocumentDoesNotExistError(Error, ValueError):
   pass
 
@@ -40,32 +32,21 @@ class Document(object):
 
   def __init__(self, pod_path, _pod, locale=None, _collection=None, body_format=None):
     utils.validate_name(pod_path)
-    self._default_locale = _pod.podspec.default_locale
+    self.default_locale = _pod.podspec.default_locale
     self.locale = locale or _pod.podspec.default_locale
+    if isinstance(self.locale, basestring):
+      self.locale = locales.Locale(self.locale)
+    if self.locale is not None:
+      self.locale.set_alias(_pod)
     self.pod_path = pod_path
     self.basename = os.path.basename(pod_path)
     self.base, self.ext = os.path.splitext(self.basename)
-
     self.pod = _pod
     self.collection = _collection
-
-    self.format = messages.extensions_to_formats.get(self.ext)
-    if self.format == messages.Format.MARKDOWN:
-      self.doc_storage = MarkdownDocumentStorage(
-          self.pod_path, self.pod, locale=locale, default_locale=self._default_locale)
-    elif self.format == messages.Format.YAML:
-      self.doc_storage = YamlDocumentStorage(
-          self.pod_path, self.pod, locale=locale, default_locale=self._default_locale)
-    elif self.format == messages.Format.HTML:
-      self.doc_storage = HtmlDocumentStorage(
-          self.pod_path, self.pod, locale=locale, default_locale=self._default_locale)
-    else:
-      formats = messages.extensions_to_formats.keys()
-      text = 'Basename "{}" does not have a valid extension. Valid formats are: {}'
-      raise BadFormatError(text.format(self.basename, ', '.join(formats)))
-
-    self.fields = self.doc_storage.fields
-    self.tagged_fields = self.doc_storage.tagged_fields
+    self.format = formats.Format.get(self)
+    self.tagged_fields = self.format.fields
+    self.fields = formats.untag_fields(copy.deepcopy(self.tagged_fields),
+                                       catalog=self.pod.catalogs.get(self.locale))
 
   def __repr__(self):
     if self.locale:
@@ -144,8 +125,11 @@ class Document(object):
 
   def get_path_format(self):
     val = None
-    if self.locale and self._default_locale and self.locale != self._default_locale:
-      if '$localization' in self.fields and 'path' in self.fields['$localization']:
+    if (self.locale
+        and self.default_locale
+        and self.locale != self.default_locale):
+      if ('$localization' in self.fields
+          and 'path' in self.fields['$localization']):
         val = self.fields['$localization']['path']
       elif self.collection.localization:
         val = self.collection.localization['path']
@@ -169,7 +153,7 @@ class Document(object):
     locale = str(self.locale)
     config = self.pod.get_podspec().get_config()
     root_path = config.get('flags', {}).get('root_path', '')
-    if locale == self._default_locale:
+    if locale == self.default_locale:
       root_path = config.get('localization', {}).get('root_path', root_path)
     path_format = (self.get_path_format()
         .replace('<grow:locale>', '{locale}')
@@ -212,12 +196,13 @@ class Document(object):
       raise
 
   def _format_path(self, path_format):
+    podspec = self.pod.get_podspec()
     return path_format.format(**{
         'base': os.path.splitext(os.path.basename(self.pod_path))[0],
         'date': self.date,
-        'locale': str(self.locale),
+        'locale': self.locale.alias if self.locale is not None else self.locale,
         'parent': self.parent if self.parent else DummyDict(),
-        'podspec': self.pod.get_podspec(),
+        'podspec': podspec,
         'slug': self.slug,
     }).replace('//', '/')
 
@@ -226,29 +211,28 @@ class Document(object):
     return self.list_locales()
 
   def list_locales(self):
-    if '$localization' in self.fields:
-      if 'locales' in self.fields['$localization']:
-        codes = self.fields['$localization']['locales']
-    codes = self.collection.list_locales()
-    return locales.Locale.parse_codes(codes)
+    if ('$localization' in self.fields
+        and 'locales' in self.fields['$localization']):
+      codes = self.fields['$localization']['locales']
+      return locales.Locale.parse_codes(codes)
+    return self.collection.list_locales()
 
   @property
   @utils.memoize
   def body(self):
-    body = self.doc_storage.body
+    body = self.format.body
     if body is None:
       return body
     return body.decode('utf-8')
 
   @property
   def content(self):
-    content = self.doc_storage.content
+    content = self.format.content
     return content.decode('utf-8')
 
   @property
   def html(self):
-    # TODO(jeremydw): Add ability to render HTML.
-    return self.doc_storage.html(self)
+    return self.format.html
 
   def __eq__(self, other):
     return (isinstance(self, Document)
@@ -288,20 +272,16 @@ class Document(object):
         content = message.content.encode('utf-8')
       else:
         content = message.content
-      self.doc_storage.write(content)
+      self.format.write(content)
     elif message.fields is not None:
       content = '---\n{}\n---\n{}\n'.format(message.fields, message.body or '')
-      self.doc_storage.write(content)
-      self.doc_storage.fields = json.loads(message.fields)
-      self.doc_storage.body = message.body or ''
-      self.fields = self.doc_storage.fields
+      self.format.write(content)
+      self.fields = self.format.fields
     else:
       raise NotImplementedError()
 
   def to_message(self):
     message = messages.DocumentMessage()
-    message.builtins = messages.BuiltInFieldsMessage()
-    message.builtins.title = self.title
     message.basename = self.basename
     message.pod_path = self.pod_path
     message.collection_path = self.collection.collection_path
@@ -310,88 +290,3 @@ class Document(object):
     message.fields = json.dumps(self.fields, cls=utils.JsonEncoder)
     message.serving_path = self.get_serving_path()
     return message
-
-
-# TODO(jeremydw): This needs a lot of cleanup. :)
-
-class BaseDocumentStorage(object):
-
-  def __init__(self, pod_path, pod, locale=None, default_locale=None):
-    # TODO(jeremydw): Only accept Locale objects, not strings.
-    self.default_locale = default_locale
-    self.locale = str(locale) if isinstance(locale, basestring) else locale
-    self.pod_path = pod_path
-    self.pod = pod
-    self.content = None
-    self.fields = {}
-    self.tagged_fields = {}
-    self.builtins = None
-    self.body = None
-    try:
-      self.load()
-    except IOError:  # Document doesn't exist.
-      pass
-
-  def load(self):
-    raise NotImplementedError
-
-  def html(self, doc):
-    return self.body
-
-  def write(self, content):
-    self.content = content
-    self.pod.write_file(self.pod_path, content)
-
-
-class YamlDocumentStorage(BaseDocumentStorage):
-
-  def load(self):
-    path = self.pod_path
-    content = self.pod.read_file(path)
-    fields, body = utils.parse_yaml(content, path=path)
-    self.content = content
-    self.fields = fields or {}
-    self.tagged_fields = {}
-    self.body = body
-    self.tagged_fields = copy.deepcopy(fields)
-    fields = untag_fields(fields)
-
-
-class HtmlDocumentStorage(YamlDocumentStorage):
-  pass
-
-
-class MarkdownDocumentStorage(BaseDocumentStorage):
-
-  def load(self):
-    path = self.pod_path
-    content = self.pod.read_file(path)
-    fields, body = utils.parse_markdown(
-        content, path=path, locale=self.locale, default_locale=self.default_locale)
-    self.content = content
-    self.fields = fields or {}
-    self.body = body
-    self.tagged_fields = copy.deepcopy(fields)
-    fields = untag_fields(fields)
-
-  def html(self, doc):
-    val = self.body
-    if val is not None:
-      extensions = [
-        tables.TableExtension(),
-        toc.TocExtension(),
-        markdown_extensions.IncludeExtension(doc.pod),
-        markdown_extensions.UrlExtension(doc.pod),
-      ]
-      val = markdown.markdown(val.decode('utf-8'), extensions=extensions)
-    return val
-
-
-def untag_fields(fields):
-  def callback(item, key, node):
-    if not isinstance(key, basestring):
-      return
-    if key.endswith('@'):
-      node[key[0:(len(key) - 1)]] = node.pop(key)
-  utils.walk(fields, callback)
-  return fields
