@@ -10,28 +10,31 @@ class RoutesTest(unittest.TestCase):
     self.pod = pods.Pod('grow/pods/testdata/pod/', storage=storage.FileStorage)
 
   def test_match(self):
-    routes = self.pod.get_routes()
-    routes.match('/')
-    routes.match('/de/about/')
-    self.assertRaises(webob.exc.HTTPNotFound, routes.match, '/dummy/')
+    self.pod.match('/')
+    self.pod.match('/de/about/')
+    self.assertRaises(webob.exc.HTTPNotFound, self.pod.match, '/dummy/')
 
   def test_list_concrete_paths(self):
     expected = [
         '/',
         '/about/',
         '/contact-us/',
-        '/intro/',
         '/de/about/',
-        '/de/contact/',
+        '/de/contact-us/',
         '/de/home/',
+        '/de/html/',
         '/de/intro/',
         '/fr/about/',
-        '/fr/contact/',
+        '/fr/contact-us/',
         '/fr/home/',
+        '/fr/html/',
         '/fr/intro/',
+        '/html/',
+        '/intro/',
         '/it/about/',
-        '/it/contact/',
+        '/it/contact-us/',
         '/it/home/',
+        '/it/html/',
         '/it/intro/',
         '/post/newer/',
         '/post/newest/',
@@ -42,7 +45,6 @@ class RoutesTest(unittest.TestCase):
         '/public/main.min.js',
     ]
     result = self.pod.routes.list_concrete_paths()
-    print result
     self.assertItemsEqual(expected, result)
 
 
