@@ -1,3 +1,4 @@
+from grow.pods import pods
 from grow.server import main
 from grow.server import handlers
 import os
@@ -8,22 +9,24 @@ import webapp2
 class PodHandlerTestCase(unittest.TestCase):
 
   def test_request(self):
+    root = os.path.join(os.path.dirname(__file__), '..', 'pods', 'testdata', 'pod')
+    pod = pods.Pod(root)
+
     # Verify application errors when no pod root is set.
-    handlers.set_pod_root(None)
+    app = main.CreateWSGIApplication()
     request = webapp2.Request.blank('/')
-    response = request.get_response(main.application)
+    response = request.get_response(app)
     self.assertEqual(response.status_int, 500)
 
     # When serving a pod, should 200.
-    root = os.path.join(os.path.dirname(__file__), '..', 'pods', 'testdata', 'pod')
-    handlers.set_pod_root(root)
+    app = main.CreateWSGIApplication(pod)
     request = webapp2.Request.blank('/')
-    response = request.get_response(main.application)
+    response = request.get_response(app)
     self.assertEqual(response.status_int, 200)
 
     # Verify 404 is sent for blank page.
     request = webapp2.Request.blank('/dummy/page/')
-    response = request.get_response(main.application)
+    response = request.get_response(app)
     self.assertEqual(response.status_int, 404)
 
 
